@@ -22,7 +22,7 @@
 #ifndef otbQtApplication_h
 #define otbQtApplication_h
 
-#include <QtGui>
+#include <QtWidgets>
 #include <QString>
 #ifndef Q_MOC_RUN  // See: https://bugreports.qt-project.org/browse/QTBUG-22829  //tag=QT4-boost-compatibility
 #include "itkMacro.h"
@@ -40,7 +40,7 @@ class OTBQtWidget_EXPORT QtApplication : public QApplication
 public:
   QtApplication(int& argc, char** argv);
 
-  bool notify(QObject *object, QEvent* event) ITK_OVERRIDE;
+  bool notify(QObject *object, QEvent* event) override;
 
 signals:
 
